@@ -20,70 +20,64 @@ from collections import OrderedDict
 import datetime
 import logging
 import os
-import urllib.parse
 from unittest import mock
+import urllib.parse
 
-from gi.repository import Gdk
-from gi.repository import GdkPixbuf
-from gi.repository import GObject
-from gi.repository import Gtk
-from gi.repository import GtkSource
-from gi.repository import Pango
+from gi.repository import Gdk, GdkPixbuf, GObject, Gtk, GtkSource, Pango
 
-from rednotebook.gui.menu import MainMenuBar
 from rednotebook.gui.options import OptionsManager
-from rednotebook.gui import customwidgets
+from rednotebook import info, templates
+from rednotebook.gui import (
+    browser,
+    browser_cef,
+    categories,
+    customwidgets,
+    editor,
+    format_menu,
+    insert_menu,
+    search,
+)
 from rednotebook.gui.customwidgets import CustomComboBoxEntry, CustomListView
-from rednotebook.util import filesystem
-from rednotebook import info
-from rednotebook import templates
-from rednotebook.util import dates
-from rednotebook.util import markup
-from rednotebook.util import urls
-from rednotebook.util import utils
-from rednotebook.gui import categories
 from rednotebook.gui.exports import ExportAssistant
-from rednotebook.gui import browser
-from rednotebook.gui import browser_cef
-from rednotebook.gui import search
-from rednotebook.gui import editor
-from rednotebook.gui import insert_menu
-from rednotebook.gui import format_menu
+from rednotebook.gui.menu import MainMenuBar
+from rednotebook.util import dates, filesystem, markup, urls, utils
 
 
 class MainWindow:
-    '''
+    """
     Class that holds the reference to the main glade file and handles
     all actions
-    '''
-    def __init__(self, journal):
+    """
 
+    def __init__(self, journal):
         self.journal = journal
 
         # Load Glade file.
         # TODO: Remove workaround for Windows once it is no longer needed.
-        self.gladefile = os.path.join(filesystem.files_dir, 'main_window.glade')
+        self.gladefile = os.path.join(filesystem.files_dir, "main_window.glade")
         self.builder = Gtk.Builder()
         # Register GtkSourceView so builder can use it when loading the file
         # https://stackoverflow.com/q/10524196/434217
         GObject.type_register(GtkSource.View)
         if filesystem.IS_WIN:
-            import xml.etree.ElementTree as ET
+            from xml.etree import ElementTree as ET
+
             tree = ET.parse(self.gladefile)
             for node in tree.iter():
-                if 'translatable' in node.attrib:
+                if "translatable" in node.attrib:
                     node.text = _(node.text)
-            xml_text = ET.tostring(tree.getroot(), encoding='unicode')
+            xml_text = ET.tostring(tree.getroot(), encoding="unicode")
             self.builder = Gtk.Builder.new_from_string(xml_text, len(xml_text))
         else:
-            self.builder.set_translation_domain('rednotebook')
+            self.builder.set_translation_domain("rednotebook")
             self.builder.add_from_file(self.gladefile)
 
-        # Get the main window and set the icon
-        self.main_frame = self.builder.get_object('main_frame')
-        self.main_frame.set_title('RedNotebook')
+        self.main_frame = self.builder.get_object("main_frame")
+        self.main_frame.set_application(journal)
+        self.main_frame.set_title("RedNotebook")
         icon = GdkPixbuf.Pixbuf.new_from_file(
-            os.path.join(filesystem.frame_icon_dir, 'rednotebook.svg'))
+            os.path.join(filesystem.frame_icon_dir, "rn-128.png")
+        )
         self.main_frame.set_icon(icon)
 
         self.is_fullscreen = False
@@ -96,46 +90,50 @@ class MainWindow:
         format_menu.FormatMenu(self)
         self.menubar_manager = MainMenuBar(self)
         self.menubar = self.menubar_manager.get_menu_bar()
-        main_vbox = self.builder.get_object('vbox3')
+        main_vbox = self.builder.get_object("vbox3")
         main_vbox.pack_start(self.menubar, False, False, 0)
         main_vbox.reorder_child(self.menubar, 0)
 
-        self.undo_action = self.uimanager.get_action('/MainMenuBar/Edit/Undo')
-        self.redo_action = self.uimanager.get_action('/MainMenuBar/Edit/Redo')
+        self.undo_action = self.uimanager.get_action("/MainMenuBar/Edit/Undo")
+        self.redo_action = self.uimanager.get_action("/MainMenuBar/Edit/Redo")
 
-        self.calendar = MainCalendar(self.journal, self.builder.get_object('calendar'))
-        self.day_text_field = DayEditor(self.builder.get_object('day_text_view'))
-        self.day_text_field.connect('can-undo-redo-changed', self.update_undo_redo_buttons)
+        self.calendar = MainCalendar(self.journal, self.builder.get_object("calendar"))
+        self.day_text_field = DayEditor(self.builder.get_object("day_text_view"))
+        self.day_text_field.connect(
+            "can-undo-redo-changed", self.update_undo_redo_buttons
+        )
         self.update_undo_redo_buttons()
         self.day_text_field.day_text_view.grab_focus()
         can_spell_check = self.day_text_field.can_spell_check()
-        spell_check_enabled = bool(self.journal.config.read('spellcheck'))
+        spell_check_enabled = bool(self.journal.config.read("spellcheck"))
         for actiongroup in self.menubar_manager.uimanager.get_action_groups():
-            if actiongroup.get_name() == 'MainMenuActionGroup':
+            if actiongroup.get_name() == "MainMenuActionGroup":
                 for action in actiongroup.list_actions():
-                    if action.get_name() == 'CheckSpelling':
+                    if action.get_name() == "CheckSpelling":
                         action.set_sensitive(can_spell_check)
                         action.set_active(spell_check_enabled and can_spell_check)
         self.day_text_field.enable_spell_check(spell_check_enabled)
 
-        self.statusbar = Statusbar(self.builder.get_object('statusbar'))
+        self.statusbar = Statusbar(self.builder.get_object("statusbar"))
 
         self.new_entry_dialog = NewEntryDialog(self)
 
         self.categories_tree_view = categories.CategoriesTreeView(
-            self.builder.get_object('categories_tree_view'), self)
+            self.builder.get_object("categories_tree_view"), self
+        )
 
         self.new_entry_dialog.categories_tree_view = self.categories_tree_view
 
-        self.back_one_day_button = self.builder.get_object('back_one_day_button')
-        self.today_button = self.builder.get_object('today_button')
-        self.forward_one_day_button = self.builder.get_object('forward_one_day_button')
+        self.back_one_day_button = self.builder.get_object("back_one_day_button")
+        self.today_button = self.builder.get_object("today_button")
+        self.forward_one_day_button = self.builder.get_object("forward_one_day_button")
 
-        self.edit_pane = self.builder.get_object('edit_pane')
-        self.text_vbox = self.builder.get_object('text_vbox')
+        self.edit_pane = self.builder.get_object("edit_pane")
+        self.text_vbox = self.builder.get_object("text_vbox")
+
+        use_internal_preview = self.journal.config.read("useInternalPreview", 1)
+        if use_internal_preview and browser.WebKit2:
 
-        use_cef = True
-        if browser.WebKit2:
             class Preview(browser.HtmlView):
                 def __init__(self, journal):
                     browser.HtmlView.__init__(self)
@@ -143,45 +141,54 @@ class MainWindow:
                     self.internal = True
 
                 def show_day(self, new_day):
-                    html = self.journal.convert(new_day.text, 'xhtml')
+                    html = self.journal.convert(
+                        new_day.text, "xhtml", use_gtk_theme=True
+                    )
                     self.load_html(html)
 
                 def shutdown(self):
                     pass
 
             self.html_editor = Preview(self.journal)
-            self.html_editor.connect('button-press-event', self.on_browser_clicked)
-            self.html_editor.connect('decide-policy', self.on_browser_decide_policy)
+            self.html_editor.connect("button-press-event", self.on_browser_clicked)
+            self.html_editor.connect("decide-policy", self.on_browser_decide_policy)
             self.text_vbox.pack_start(self.html_editor, True, True, 0)
             self.html_editor.set_editable(False)
-        elif browser_cef.cef and use_cef:
-            class Preview(browser_cef.HtmlView):
+        elif use_internal_preview and browser_cef.get_html_view_class():
+            HtmlView = browser_cef.get_html_view_class()
+
+            class Preview(HtmlView):
                 def __init__(self, journal):
                     super().__init__()
                     self.journal = journal
                     self.internal = True
 
                 def show_day(self, new_day):
-                    html = self.journal.convert(new_day.text, 'xhtml')
+                    html = self.journal.convert(
+                        new_day.text, "xhtml", use_gtk_theme=True
+                    )
                     self.load_html(html)
 
                 def highlight(self, text):
                     pass
 
             self.html_editor = Preview(self.journal)
+            self.html_editor.connect(
+                "on-url-clicked", lambda _, url: self.navigate_to_uri(url)
+            )
             self.text_vbox.pack_start(self.html_editor, True, True, 0)
         else:
             self.html_editor = mock.MagicMock()
             self.html_editor.internal = False
-            preview_button = self.builder.get_object('preview_button')
-            preview_button.set_label(_('Preview in Browser'))
+            preview_button = self.builder.get_object("preview_button")
+            preview_button.set_label(_("Preview in Browser"))
 
         self.html_editor.hide()
 
         self.preview_mode = False
 
         # Let the edit_paned respect its childs size requests
-        self.edit_pane.child_set_property(self.text_vbox, 'shrink', False)
+        self.edit_pane.child_set_property(self.text_vbox, "shrink", False)
 
         # Add InfoBar.
         self.infobar = customwidgets.Info()
@@ -207,20 +214,15 @@ class MainWindow:
 
         # Create an event->method dictionary and connect it to the widgets
         dic = {
-            'on_back_one_day_button_clicked': self.on_back_one_day_button_clicked,
-            'on_today_button_clicked': self.on_today_button_clicked,
-            'on_forward_one_day_button_clicked': self.on_forward_one_day_button_clicked,
-
-            'on_preview_button_clicked': self.on_preview_button_clicked,
-            'on_edit_button_clicked': self.on_edit_button_clicked,
-
-            'on_main_frame_configure_event': self.on_main_frame_configure_event,
-            'on_main_frame_window_state_event': self.on_main_frame_window_state_event,
-
-            'on_add_new_entry_button_clicked': self.on_add_new_entry_button_clicked,
-
-            'on_main_frame_delete_event': self.on_main_frame_delete_event,
-
+            "on_back_one_day_button_clicked": self.on_back_one_day_button_clicked,
+            "on_today_button_clicked": self.on_today_button_clicked,
+            "on_forward_one_day_button_clicked": self.on_forward_one_day_button_clicked,
+            "on_preview_button_clicked": self.on_preview_button_clicked,
+            "on_edit_button_clicked": self.on_edit_button_clicked,
+            "on_main_frame_configure_event": self.on_main_frame_configure_event,
+            "on_main_frame_window_state_event": self.on_main_frame_window_state_event,
+            "on_add_new_entry_button_clicked": self.on_add_new_entry_button_clicked,
+            "on_main_frame_delete_event": self.on_main_frame_delete_event,
             # connect_signals can only be called once, it seems
             # Otherwise RuntimeWarnings are raised: RuntimeWarning: missing handler '...'
         }
@@ -237,43 +239,44 @@ class MainWindow:
         self.setup_tray_icon()
 
         # Show/hide the "tags" panel on the right.
-        self.builder.get_object('annotations_pane').set_visible(
-            self.journal.config.read('showTagsPane'))
+        self.builder.get_object("annotations_pane").set_visible(
+            self.journal.config.read("showTagsPane")
+        )
 
     def set_tooltips(self):
-        '''
+        """
         Little work-around:
         Tooltips are not shown for menuitems that have been created with uimanager.
         We have to do it manually.
-        '''
+        """
         groups = self.uimanager.get_action_groups()
         for group in groups:
             actions = group.list_actions()
             for action in actions:
                 widgets = action.get_proxies()
-                tooltip = action.get_property('tooltip')
-                if tooltip:
+                if tooltip := action.get_property("tooltip"):
                     for widget in widgets:
                         widget.set_tooltip_markup(tooltip)
 
     def set_shortcuts(self):
-        '''
+        """
         This method actually is not responsible for the Ctrl-C etc. actions
-        '''
-        self.accel_group = self.builder.get_object('accelgroup1')
+        """
+        self.accel_group = self.builder.get_object("accelgroup1")
         self.main_frame.add_accel_group(self.accel_group)
 
-        self.main_frame.connect('key-press-event', self._on_key_press_event)
+        self.main_frame.connect("key-press-event", self._on_key_press_event)
 
         shortcuts = [
-            (self.back_one_day_button, 'clicked', '<Ctrl>Page_Up'),
-            (self.today_button, 'clicked', '<Alt>Home'),
-            (self.forward_one_day_button, 'clicked', '<Ctrl>Page_Down'),
+            (self.back_one_day_button, "clicked", "<Ctrl>Page_Up"),
+            (self.today_button, "clicked", "<Alt>Home"),
+            (self.forward_one_day_button, "clicked", "<Ctrl>Page_Down"),
         ]
         for button, signal, shortcut in shortcuts:
             (keyval, mod) = Gtk.accelerator_parse(shortcut)
-            button.add_accelerator(signal, self.accel_group,
-                                   keyval, mod, Gtk.AccelFlags.VISIBLE)
+            button.add_accelerator(
+                signal, self.accel_group, keyval, mod, Gtk.AccelFlags.VISIBLE
+            )
 
     def _on_key_press_event(self, widget, event):
         # Exit fullscreen mode with ESC.
@@ -284,47 +287,54 @@ class MainWindow:
 
     def setup_tray_icon(self):
         self.tray_icon = Gtk.StatusIcon()
-        self.tray_icon.set_name('RedNotebook')
-        visible = (self.journal.config.read('closeToTray') == 1)
+        self.tray_icon.set_name("RedNotebook")
+        visible = self.journal.config.read("closeToTray") == 1
         self.tray_icon.set_visible(visible)
-        logging.debug('Tray icon visible: %s' % visible)
+        logging.debug(f"Tray icon visible: {visible}")
 
-        self.tray_icon.set_tooltip_text('RedNotebook')
-        # TODO: Try using the svg here as well.
-        icon_file = os.path.join(self.journal.dirs.frame_icon_dir, 'rn-32.png')
+        self.tray_icon.set_tooltip_text("RedNotebook")
+        icon_file = os.path.join(self.journal.dirs.frame_icon_dir, "rn-32.png")
         self.tray_icon.set_from_file(icon_file)
 
-        self.tray_icon.connect('activate', self.on_tray_icon_activated)
-        self.tray_icon.connect('popup-menu', self.on_tray_popup_menu)
+        self.tray_icon.connect("activate", self.on_tray_icon_activated)
+        self.tray_icon.connect("popup-menu", self.on_tray_popup_menu)
 
     def on_tray_icon_activated(self, tray_icon):
-        if self.main_frame.get_property('visible'):
+        if self.main_frame.get_property("visible"):
             self.hide()
         else:
             self.show()
 
     def on_tray_popup_menu(self, _status_icon, button, activate_time):
-        '''
+        """
         Called when the user right-clicks the tray icon
-        '''
+        """
 
-        tray_menu_xml = '''
+        tray_menu_xml = """
         <ui>
         <popup action="TrayMenu">
             <menuitem action="Show"/>
             <menuitem action="Quit"/>
         </popup>
-        </ui>'''
+        </ui>"""
 
         # Create an ActionGroup
-        actiongroup = Gtk.ActionGroup('TrayActionGroup')
+        actiongroup = Gtk.ActionGroup("TrayActionGroup")
 
         # Create actions
-        actiongroup.add_actions([
-            ('Show', Gtk.STOCK_MEDIA_PLAY, _('Show RedNotebook'),
-                None, None, lambda widget: self.show()),
-            ('Quit', Gtk.STOCK_QUIT, None, None, None, self.on_quit_activate),
-        ])
+        actiongroup.add_actions(
+            [
+                (
+                    "Show",
+                    None,
+                    _("Show RedNotebook"),
+                    None,
+                    None,
+                    lambda widget: self.show(),
+                ),
+                ("Quit", None, None, None, None, self.on_quit_activate),
+            ]
+        )
 
         # Add the actiongroup to the uimanager
         self.uimanager.insert_action_group(actiongroup, 0)
@@ -333,7 +343,7 @@ class MainWindow:
         self.uimanager.add_ui_from_string(tray_menu_xml)
 
         # Create a Menu
-        menu = self.uimanager.get_widget('/TrayMenu')
+        menu = self.uimanager.get_widget("/TrayMenu")
 
         menu.popup(None, None, None, None, button, activate_time)
 
@@ -347,12 +357,12 @@ class MainWindow:
         self.main_frame.hide()
 
     def on_main_frame_delete_event(self, widget, event):
-        '''
+        """
         Exit if not close_to_tray
-        '''
-        logging.debug('Main frame destroyed')
+        """
+        logging.debug("Main frame destroyed")
 
-        if self.journal.config.read('closeToTray'):
+        if self.journal.config.read("closeToTray"):
             self.hide()
         else:
             self.html_editor.shutdown()
@@ -363,19 +373,19 @@ class MainWindow:
         return True
 
     def on_quit_activate(self, widget):
-        '''
+        """
         User selected quit from the menu -> exit unconditionally
-        '''
+        """
         self.journal.exit()
 
     # -------------------------------------------------------- TRAY-ICON / CLOSE
 
     def setup_stats_dialog(self):
-        self.stats_dialog = self.builder.get_object('stats_dialog')
+        self.stats_dialog = self.builder.get_object("stats_dialog")
         self.stats_dialog.set_transient_for(self.main_frame)
-        overall_box = self.builder.get_object('overall_box')
-        day_box = self.builder.get_object('day_stats_box')
-        columns = [('1', str), ('2', str)]
+        overall_box = self.builder.get_object("overall_box")
+        day_box = self.builder.get_object("day_stats_box")
+        columns = [("1", str), ("2", str)]
         overall_list = CustomListView(columns)
         day_list = CustomListView(columns)
         overall_box.pack_start(overall_list, True, True, 0)
@@ -388,9 +398,9 @@ class MainWindow:
     # MODE-SWITCHING -----------------------------------------------------------
 
     def change_mode(self, preview):
-        edit_scroll = self.builder.get_object('text_scrolledwindow')
-        edit_button = self.builder.get_object('edit_button')
-        preview_button = self.builder.get_object('preview_button')
+        edit_scroll = self.builder.get_object("text_scrolledwindow")
+        edit_button = self.builder.get_object("edit_button")
+        preview_button = self.builder.get_object("preview_button")
 
         size_group = Gtk.SizeGroup(Gtk.SizeGroupMode.HORIZONTAL)
         size_group.add_widget(edit_button)
@@ -424,8 +434,10 @@ class MainWindow:
         self.format_actiongroup.set_sensitive(not preview)
         self.insert_button.set_sensitive(not preview)
         self.format_button.set_sensitive(not preview)
-        for action in ['Cut', 'Paste']:
-            self.uimanager.get_widget('/MainMenuBar/Edit/%s' % action).set_sensitive(not preview)
+        for action in ["Cut", "Paste"]:
+            self.uimanager.get_widget(f"/MainMenuBar/Edit/{action}").set_sensitive(
+                not preview
+            )
 
         self.preview_mode = preview
 
@@ -442,15 +454,18 @@ class MainWindow:
             self.html_editor.show_day(self.day)
             self.change_mode(preview=True)
         else:
-            date_format = self.journal.config.read('exportDateFormat')
+            date_format = self.journal.config.read("exportDateFormat")
             date_string = dates.format_date(date_format, self.day.date)
-            markup_string = markup.get_markup_for_day(self.day)
+            markup_string = markup.get_markup_for_day(self.day, "xhtml")
             html = self.journal.convert(
-                markup_string, 'xhtml',
-                headers=[date_string + ' - RedNotebook', '', ''],
-                options={'toc': 0})
+                markup_string,
+                "xhtml",
+                headers=[f"{date_string} - RedNotebook", "", ""],
+                options={"toc": 0},
+            )
             utils.show_html_in_browser(
-                html, os.path.join(self.journal.dirs.temp_dir, 'day.html'))
+                html, os.path.join(self.journal.dirs.temp_dir, "day.html")
+            )
 
     def on_browser_clicked(self, webview, event):
         if event.type == Gdk.EventType._2BUTTON_PRESS:
@@ -474,39 +489,44 @@ class MainWindow:
         self.search_scroll.add(self.search_tree_view)
         self.search_box = search.SearchComboBox(Gtk.ComboBox.new_with_entry(), self)
         self.search_box.combo_box.show()
-        search_container = self.builder.get_object('search_container')
+        self.replace_box = search.ReplaceBox(self)
+        search_container = self.builder.get_object("search_container")
         search_container.pack_start(self.search_box.combo_box, False, False, 0)
+        search_container.pack_start(self.replace_box, False, True, 0)
         search_container.pack_start(self.search_scroll, True, True, 0)
 
     def setup_clouds(self):
         if browser.WebKit2:
             from rednotebook.gui import clouds
+
             self.cloud = clouds.Cloud(self.journal)
-            self.builder.get_object('search_container').pack_end(self.cloud, True, True, 0)
+            self.builder.get_object("search_container").pack_end(
+                self.cloud, True, True, 0
+            )
         else:
             self.cloud = mock.MagicMock()
 
     def on_main_frame_configure_event(self, widget, event):
-        '''
+        """
         Is called when the frame size is changed. Unfortunately this is
         the way to go as asking for frame.get_size() at program termination
         gives strange results.
-        '''
+        """
         main_frame_width, main_frame_height = self.main_frame.get_size()
-        self.journal.config['mainFrameWidth'] = main_frame_width
-        self.journal.config['mainFrameHeight'] = main_frame_height
+        self.journal.config["mainFrameWidth"] = main_frame_width
+        self.journal.config["mainFrameHeight"] = main_frame_height
 
     def on_main_frame_window_state_event(self, widget, event):
-        '''
+        """
         The "window-state-event" signal is emitted when window state
         of widget changes. For example, for a toplevel window this
         event is signaled when the window is iconified, deiconified,
         minimized, maximized, made sticky, made not sticky, shaded or
         unshaded.
-        '''
+        """
         if event.changed_mask & Gdk.WindowState.MAXIMIZED:
             maximized = bool(event.new_window_state & Gdk.WindowState.MAXIMIZED)
-            self.journal.config['mainFrameMaximized'] = int(maximized)
+            self.journal.config["mainFrameMaximized"] = int(maximized)
 
     def toggle_fullscreen(self):
         if self.is_fullscreen:
@@ -527,36 +547,37 @@ class MainWindow:
         self.journal.go_to_next_day()
 
     def on_browser_decide_policy(self, webview, decision, decision_type):
-        '''
+        """
         We want to load files and links externally.
-        '''
+        """
         if decision_type == browser.WebKit2.PolicyDecisionType.NAVIGATION_ACTION:
             action = decision.get_navigation_action()
             if action.is_user_gesture():
                 uri = action.get_request().get_uri()
-                logging.info('Clicked URI "%s"' % uri)
-
-                if urls.is_entry_reference_uri(uri):
-                    self.navigate_to_referenced_entry(uri)
-                else:
-                    urls.open_url(uri)
-
+                self.navigate_to_uri(uri)
                 decision.ignore()
 
         # Stop processing this event.
         return True
 
+    def navigate_to_uri(self, uri):
+        logging.info(f'Navigating to URI "{uri}"')
+        if urls.is_entry_reference_uri(uri):
+            self.navigate_to_referenced_entry(uri)
+        else:
+            urls.open_url(uri)
+
     def navigate_to_referenced_entry(self, entry_reference_uri):
         entry_reference_uri = urllib.parse.urlparse(entry_reference_uri)
         date = dates.get_date_from_date_string(entry_reference_uri.fragment)
         self.journal.change_date(date)
 
     def get_new_journal_dir(self, title, message):
-        dir_chooser = self.builder.get_object('dir_chooser')
+        dir_chooser = self.builder.get_object("dir_chooser")
         dir_chooser.set_transient_for(self.main_frame)
-        label = self.builder.get_object('dir_chooser_label')
+        label = self.builder.get_object("dir_chooser_label")
 
-        label.set_markup('<b>' + message + '</b>')
+        label.set_markup(f"<b>{message}</b>")
         dir_chooser.set_current_folder(os.path.dirname(self.journal.dirs.data_dir))
 
         response = dir_chooser.run()
@@ -566,16 +587,16 @@ class MainWindow:
 
         if response == Gtk.ResponseType.OK:
             if new_dir is None:
-                self.journal.show_message(_('No directory selected.'), error=True)
+                self.journal.show_message(_("No directory selected."), error=True)
                 return None
             return new_dir
         return None
 
     def show_save_error_dialog(self, exit_imminent):
-        dialog = self.builder.get_object('save_error_dialog')
+        dialog = self.builder.get_object("save_error_dialog")
         dialog.set_transient_for(self.main_frame)
 
-        exit_without_save_button = self.builder.get_object('exit_without_save_button')
+        exit_without_save_button = self.builder.get_object("exit_without_save_button")
         if exit_imminent:
             exit_without_save_button.show()
         else:
@@ -596,21 +617,21 @@ class MainWindow:
     def add_values_to_config(self):
         config = self.journal.config
 
-        left_div = self.builder.get_object('main_pane').get_position()
-        config['leftDividerPosition'] = left_div
+        left_div = self.builder.get_object("main_pane").get_position()
+        config["leftDividerPosition"] = left_div
 
         right_div = self.edit_pane.get_position()
-        config['rightDividerPosition'] = right_div
+        config["rightDividerPosition"] = right_div
 
         # Remember if window was maximized in separate method
 
         # Remember window position
-        config['mainFrameX'], config['mainFrameY'] = self.main_frame.get_position()
+        config["mainFrameX"], config["mainFrameY"] = self.main_frame.get_position()
 
     def load_values_from_config(self):
         config = self.journal.config
-        main_frame_width = config.read('mainFrameWidth')
-        main_frame_height = config.read('mainFrameHeight')
+        main_frame_width = config.read("mainFrameWidth")
+        main_frame_height = config.read("mainFrameHeight")
 
         screen_width = Gdk.Screen.width()
         screen_height = Gdk.Screen.height()
@@ -620,12 +641,12 @@ class MainWindow:
 
         self.main_frame.resize(main_frame_width, main_frame_height)
 
-        if config.read('mainFrameMaximized'):
+        if config.read("mainFrameMaximized"):
             self.main_frame.maximize()
         else:
             # If window is not maximized, restore last position
-            x = config.read('mainFrameX')
-            y = config.read('mainFrameY')
+            x = config.read("mainFrameX")
+            y = config.read("mainFrameY")
             try:
                 x, y = int(x), int(y)
                 # Set to 0 if value is below 0
@@ -637,28 +658,38 @@ class MainWindow:
                 # Values have not been set or are not valid integers
                 self.main_frame.set_position(Gtk.WindowPosition.CENTER)
 
-        self.builder.get_object('main_pane').set_position(config.read('leftDividerPosition'))
+        self.builder.get_object("main_pane").set_position(
+            config.read("leftDividerPosition")
+        )
         # By default do not show tags pane.
-        self.edit_pane.set_position(config.read('rightDividerPosition', main_frame_width))
+        self.edit_pane.set_position(
+            config.read("rightDividerPosition", main_frame_width)
+        )
 
-        self.set_font(config.read('mainFont', editor.DEFAULT_FONT))
+        self.set_font(config.read("mainFont", editor.DEFAULT_FONT))
 
     def set_font(self, font_name):
         self.day_text_field.set_font(font_name)
-        self.html_editor.set_font_size(Pango.FontDescription(font_name).get_size() / Pango.SCALE)
+        self.html_editor.set_font_size(
+            Pango.FontDescription(font_name).get_size() / Pango.SCALE
+        )
 
     def setup_template_menu(self):
         def update_menu(button):
             self.template_button.set_menu(self.template_manager.get_menu())
 
         self.template_button = customwidgets.ToolbarMenuButton(
-            Gtk.STOCK_PASTE, self.template_manager.get_menu())
-        self.template_button.set_label(_('Template'))
-        self.template_button.connect('clicked', update_menu)
-        self.template_button.set_tooltip_text(_(
-            "Insert this weekday's template. "
-            "Click the arrow on the right for more options"))
-        self.builder.get_object('edit_toolbar').insert(self.template_button, 2)
+            "edit-paste", self.template_manager.get_menu()
+        )
+        self.template_button.set_label(_("Template"))
+        self.template_button.connect("clicked", update_menu)
+        self.template_button.set_tooltip_text(
+            _(
+                "Insert this weekday's template. "
+                "Click the arrow on the right for more options"
+            )
+        )
+        self.builder.get_object("edit_toolbar").insert(self.template_button, 2)
 
     def on_add_new_entry_button_clicked(self, widget):
         self.categories_tree_view._on_add_entry_clicked(None)
@@ -679,7 +710,7 @@ class MainWindow:
         self.day_text_field.show_day(day)
 
         # Only switch mode automatically if set in preferences.
-        if self.journal.config.read('autoSwitchMode') and self.html_editor.internal:
+        if self.journal.config.read("autoSwitchMode") and self.html_editor.internal:
             if day.has_text and not self.preview_mode:
                 self.change_mode(preview=True)
             elif not day.has_text and self.preview_mode:
@@ -691,6 +722,9 @@ class MainWindow:
 
         self.categories_tree_view.set_day_content(day)
 
+    def set_day_text(self, new_text):
+        self.day_text_field.set_text(new_text)
+
     def get_day_text(self):
         return self.day_text_field.get_text()
 
@@ -741,7 +775,7 @@ class DayEditor(editor.Editor):
             if filesystem.files_dir not in search_path:
                 search_path.insert(0, filesystem.files_dir)
                 lm.set_search_path(search_path)
-            self._t2t_highlighting = lm.get_language('t2t')
+            self._t2t_highlighting = lm.get_language("t2t")
         return self._t2t_highlighting
 
     def _get_style_scheme(self):
@@ -750,15 +784,15 @@ class DayEditor(editor.Editor):
             sm = GtkSource.StyleSchemeManager.get_default()
             if filesystem.files_dir not in sm.get_search_path():
                 sm.prepend_search_path(filesystem.files_dir)
-            self._style_scheme = sm.get_scheme('rednotebook')
+            self._style_scheme = sm.get_scheme("rednotebook")
         return self._style_scheme
 
     def _get_buffer(self, key, text):
-        '''Get an editing buffer for a given item
+        """Get an editing buffer for a given item
 
         If key is in our cache of recently used buffers, its buffer is retrieved
         and text is ignored. Otherwise, a new buffer is constructed with text.
-        '''
+        """
         if key in self.recent_buffers:
             self.recent_buffers.move_to_end(key)
             return self.recent_buffers[key]
@@ -766,7 +800,7 @@ class DayEditor(editor.Editor):
         buf = self.recent_buffers[key] = GtkSource.Buffer.new()
         buf.set_style_scheme(self._get_style_scheme())
         buf.set_language(self._get_t2t_highlighting())
-        buf.create_tag('highlighter', background='Yellow')
+        buf.create_tag("highlighter", background="Yellow")
         buf.begin_not_undoable_action()
         buf.set_text(text)
         buf.end_not_undoable_action()
@@ -798,7 +832,7 @@ class DayEditor(editor.Editor):
             return
 
     def show_template(self, title, text):
-        buf = self._get_buffer(('template', title), text)
+        buf = self._get_buffer(("template", title), text)
         self.replace_buffer(buf)
         self.day_text_view.grab_focus()
 
@@ -808,28 +842,31 @@ class DayEditor(editor.Editor):
 
 class NewEntryDialog:
     def __init__(self, main_frame):
-        dialog = main_frame.builder.get_object('new_entry_dialog')
+        dialog = main_frame.builder.get_object("new_entry_dialog")
         self.dialog = dialog
         dialog.set_transient_for(main_frame.main_frame)
 
         self.main_frame = main_frame
         self.journal = self.main_frame.journal
         self.categories_combo_box = CustomComboBoxEntry(
-            main_frame.builder.get_object('categories_combo_box'))
+            main_frame.builder.get_object("categories_combo_box")
+        )
         self.new_entry_combo_box = CustomComboBoxEntry(
-            main_frame.builder.get_object('entry_combo_box'))
+            main_frame.builder.get_object("entry_combo_box")
+        )
 
         # Let the user finish a new category entry by hitting ENTER
         def respond(widget):
             if self._text_entered():
                 self.dialog.response(Gtk.ResponseType.OK)
-        self.new_entry_combo_box.entry.connect('activate', respond)
-        self.categories_combo_box.entry.connect('activate', respond)
 
-        self.categories_combo_box.combo_box.connect('changed', self.on_category_changed)
+        self.new_entry_combo_box.entry.connect("activate", respond)
+        self.categories_combo_box.entry.connect("activate", respond)
+
+        self.categories_combo_box.combo_box.connect("changed", self.on_category_changed)
 
     def on_category_changed(self, widget):
-        '''Show old entries in ComboBox when a new category is selected'''
+        """Show old entries in ComboBox when a new category is selected"""
         category = self.categories_combo_box.get_active_text()
         old_entries = self.journal.get_entries(category)
         self.new_entry_combo_box.set_entries(old_entries)
@@ -840,7 +877,7 @@ class NewEntryDialog:
     def _text_entered(self):
         return bool(self.categories_combo_box.get_active_text())
 
-    def show_dialog(self, category=''):
+    def show_dialog(self, category=""):
         # Use last used category.
         last_category = self.categories_tree_view.last_category
 
@@ -850,7 +887,7 @@ class NewEntryDialog:
         # Show the list of categories
         self.categories_combo_box.set_entries(self.categories_tree_view.categories)
 
-        self.categories_combo_box.set_active_text(category or last_category or '')
+        self.categories_combo_box.set_active_text(category or last_category or "")
 
         if category:
             # We already know the category so let's get the entry
@@ -861,7 +898,7 @@ class NewEntryDialog:
         response = self.dialog.run()
         self.dialog.hide()
 
-        if not response == Gtk.ResponseType.OK:
+        if response != Gtk.ResponseType.OK:
             return
 
         category_name = self.categories_combo_box.get_active_text()
@@ -894,10 +931,7 @@ class Statusbar:
             self.start_countdown()
 
     def show_message(self, title, msg, msg_type):
-        if title and msg:
-            text = '{}: {}'.format(title, msg)
-        else:
-            text = title or msg
+        text = f"{title}: {msg}" if title and msg else title or msg
         self._show_text(text)
 
     def start_countdown(self):
@@ -908,7 +942,7 @@ class Statusbar:
         self.time_left -= 1
         if self.time_left <= 0:
             GObject.source_remove(self.countdown)
-            self._show_text('', countdown=False)
+            self._show_text("", countdown=False)
         return True
 
 
@@ -917,10 +951,10 @@ class MainCalendar:
         self.journal = journal
         self.calendar = calendar
 
-        if self.journal.config.read('weekNumbers'):
-            calendar.set_property('show-week-numbers', True)
+        if self.journal.config.read("weekNumbers"):
+            calendar.set_property("show-week-numbers", True)
 
-        self.date_listener = self.calendar.connect('day-selected', self.on_day_selected)
+        self.date_listener = self.calendar.connect("day-selected", self.on_day_selected)
 
     def on_day_selected(self, _cal):
         self.journal.change_date(self.get_date())
@@ -949,12 +983,12 @@ class MainCalendar:
         return datetime.date(year, month + 1, day)
 
     def set_day_edited(self, day_number, edited):
-        '''
+        """
         It may happen that we try to mark a day that is non-existent in this month
         if we switch by clicking on the calendar e.g. from Aug 31 to Sep 1.
         The month has already changed and there is no Sep 31.
         Still save_old_day tries to mark the 31st.
-        '''
+        """
         if not self._check_date(day_number):
             return
 
@@ -969,17 +1003,19 @@ class MainCalendar:
             self.set_day_edited(day_number, not day.empty)
 
     def _check_date(self, day_number):
-        '''
+        """
         E.g. It may happen that text is edited on the 31.7. and then the month
         is changed to June. There is no 31st in June, so we don't mark anything
         in the calendar. This behaviour is necessary since we use the calendar
         both for navigating and showing the current date.
-        '''
+        """
         cal_year, cal_month, _cal_day = self.calendar.get_date()
         cal_month += 1
-        if day_number not in range(1, dates.get_number_of_days(cal_year, cal_month) + 1):
+        if day_number not in range(
+            1, dates.get_number_of_days(cal_year, cal_month) + 1
+        ):
             logging.debug(
-                'Non-existent date in calendar: %s.%s.%s' %
-                (day_number, cal_month, cal_year))
+                f"Non-existent date in calendar: {day_number}.{cal_month}.{cal_year}"
+            )
             return False
         return True
